==> cramr_ui_lib-1.0.10.tar.gz: test/ads/banner_ad_widget_test.dart <==
import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/multi_conjugation_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/multi_conjugation_verb_selection_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

main() {
  testWidgets('Tests the preloaded banner ad widget',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController;
    const testKey = Key('testKey');
    MultiConjugationBannerAdWidget bannerAdWidget =
        const MultiConjugationBannerAdWidget(
      key: testKey,
    );
    await tester.pumpWidget(MultiProvider(providers: [
      Provider<AdsController?>(
        create: (BuildContext context) {
          adsController = AdsController(MobileAds.instance);
          adsController?.initialize();
          return adsController;
        },
      ),
      ChangeNotifierProvider(
        create: (BuildContext context) {
          var model = VerbTestModel();
          model.initialise(_randomIndicative, _randomPronouns,
              _randomInfinitive, 'fr', 'translation', _mode, _tense);
          int i = 0;
          for (var element in _randomIndicative) {
            model.add(element, i++);
          }
          return model;
        },
        child: MaterialApp(
          home: MultiConjugationVerbSelectionRoute(SettingsController(
              SettingsService(prefs), ThemeMode.dark, prefs)),
        ),
      )
    ], child: MaterialApp(home: bannerAdWidget)));
    expect(find.byKey(testKey), findsOneWidget);
  });
}

==> cramr_ui_lib-1.0.11.tar.gz: test/ads/banner_ad_widget_test.dart <==
import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/multi_conjugation_banner_ad_widget.dart';
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/multi_conjugation_verb_selection_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

main() {
  testWidgets('Tests the preloaded banner ad widget',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController;
    const testKey = Key('testKey');
    MultiConjugationBannerAdWidget bannerAdWidget =
        MultiConjugationBannerAdWidget(
      key: testKey,
    );
    await tester.pumpWidget(MultiProvider(providers: [
      Provider<AdsController?>(
        create: (BuildContext context) {
          adsController = AdsController(MobileAds.instance);
          adsController?.initialize();
          return adsController;
        },
      ),
      ChangeNotifierProvider(
        create: (BuildContext context) {
          var model = VerbTestModel();
          model.initialise(_randomIndicative, _randomPronouns,
              _randomInfinitive, 'fr', 'translation', _mode, _tense);
          int i = 0;
          for (var element in _randomIndicative) {
            model.add(element, i++);
          }
          return model;
        },
        child: MaterialApp(
          home: MultiConjugationVerbSelectionRoute(
            SettingsController(SettingsService(prefs), ThemeMode.dark, prefs),
            safeBannerAdWidget: const SafeBannerAdWidget(
              adUnitId: '',
              adRequest: AdRequest(),
            ),
          ),
        ),
      )
    ], child: MaterialApp(home: bannerAdWidget)));
    expect(find.byKey(testKey), findsOneWidget);
  });
}
